@@ -17,13 +17,10 @@ class SenderEmailConfigurationAdmin(admin.ModelAdmin):
 @admin.register(EmailConfiguration)
 class EmailConfigurationAdmin(admin.ModelAdmin):
     list_display = ('Subject',
-                    'Logo',
-                    'Banner',
                     'Email_Content',
                     'Signature',
                     'Email_Us',
                     'FAQ_URL',
                     'Unsubscribe_Email_ID',
                     'Logs_Type',
-                    'HTML_File',
                     )
