@@ -24,11 +24,10 @@ def send_log_email():
     sender = sender_email_configuration.sender_email_address
 
     email_configuration = EmailConfiguration.objects.filter(
-        Logs_Type='Attachment').values('Subject', 'Logo', 'Banner',
-                                       'Email_Content', 'Signature',
-                                       'Email_Us', 'FAQ_URL',
-                                       'Unsubscribe_Email_ID', 'Logs_Type',
-                                       'HTML_File').first()
+        Logs_Type='Attachment').value('Subject', 'Email_Content', 'Signature',
+                                      'Email_Us', 'FAQ_URL',
+                                      'Unsubscribe_Email_ID', 'Logs_Type'
+                                      ).first()
 
     send_notifications(email, sender, email_configuration)
 
@@ -37,11 +36,10 @@ def send_log_email_with_msg(email, sender, msg):
     """ function to send emails of log file to personas"""
 
     email_configuration = EmailConfiguration.objects.filter(
-        Logs_Type='Message').values('Subject', 'Logo', 'Banner',
-                                    'Email_Content', 'Signature',
-                                    'Email_Us', 'FAQ_URL',
-                                    'Unsubscribe_Email_ID', 'Logs_Type',
-                                    'HTML_File').first()
+        Logs_Type='Attachment').value('Subject', 'Email_Content', 'Signature',
+                                      'Email_Us', 'FAQ_URL',
+                                      'Unsubscribe_Email_ID', 'Logs_Type'
+                                      ).first()
 
     # Getting sender email id
     send_notifications_with_msg(email, sender, msg, email_configuration)
