@@ -4,7 +4,7 @@ import boto3
 from botocore.exceptions import ClientError
 from django.conf import settings
 from django.core.mail import EmailMessage
-
+# from openlxp_notifications.media import HTML_files
 logger = logging.getLogger('dict_config_logger')
 
 
@@ -56,11 +56,6 @@ def send_notifications(email, sender, email_configuration):
     # is still in the sandbox, this address must be verified.
     RECIPIENT = email
 
-    # Getting path of email cover picture and logo picture
-    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
-    logger.info(cover)
-    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
-    logger.info(logo)
     # The subject line for the email.
     SUBJECT = email_configuration.get('Subject')
 
@@ -68,10 +63,9 @@ def send_notifications(email, sender, email_configuration):
     # LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
 
-    # # The HTML body of the email.
-    file_name = email_configuration.get('HTML_File')
-    BODY_HTML = open('media/' + file_name).read().format(
-        cover=cover, logo=logo,
+    # The HTML body of the email.
+    file_name = 'Email_Template.html'
+    BODY_HTML = open(file_name).read().format(
         paragraph=email_configuration.get('Email_Content'),
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
@@ -116,13 +110,9 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
     # The subject line for the email.
     SUBJECT = email_configuration.get('Subject')
 
-    # Getting path of email cover picture and logo picture
-    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
-    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
     # # The HTML body of the email.
-    file_name = email_configuration.get('HTML_File')
+    file_name = 'Email_Template.html'
     BODY_HTML = open('media/' + file_name).read().format(
-        cover=cover, logo=logo,
         paragraph=msg,
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
