@@ -52,18 +52,13 @@ class EmailConfiguration(TimeStampedModel):
 
     Subject = models.CharField(max_length=200, null=True)
 
-    Logo = models.ImageField(upload_to='logo_pic', default='logo.jpg',
-                             help_text="Please upload your logo here")
-
-    Banner = models.ImageField(upload_to='banner_pic', default='banner.jpg',
-                               help_text="Please upload your banner here")
-
     Email_Content = models.TextField(max_length=200, null=True)
 
     Signature = models.TextField(max_length=200, null=True)
 
     Email_Us = models.EmailField(max_length=254,
-                                 help_text='Enter email address')
+                                 help_text='Enter email address',
+                                 null= True)
 
     FAQ_URL = models.CharField(max_length=200, null=True)
 
@@ -71,8 +66,6 @@ class EmailConfiguration(TimeStampedModel):
                                              help_text='Enter email address')
     Logs_Type = models.CharField(max_length=200, choices=LOG_TYPE_CHOICES,
                                  null=True)
-    HTML_File = models.FileField(upload_to='HTML_files',
-                                 help_text='Upload the html file')
 
     def get_absolute_url(self):
         """ URL for displaying individual model records."""
